
Other Supporting Standards
==========================

The section contains modules that implement supporting specifications
that are not specific, or at least have no special interest in the
domains of Learning, Education and Training.  In some cases modules
provide utilities to help interface with Python's standard libraries.

Contents:

.. toctree::
   :maxdepth: 2

   wsgi
   xml
   html401
   rfc2396
   urn
   rfc4287
   rfc5023
   iso8601
   unicode5
   streams
   vfs